
.. _library-api:

=========================
Library API Documentation
=========================
The page contains the module-level documentation for each of the 
importable modules in ``docp-core``.

Module Documentation
====================
In addition to the module-level documentation, most of the public 
classes and/or methods come with one or more usage examples and access
to the source code itself.

There are two type of modules listed here:

    - Those whose API is designed to be accessed by the user/caller
    - Those which are designated 'private' and designed only for internal
      use

We've exposed both here for completeness and to aid in understanding how
the library is implemented:

.. toctree:: 
   :maxdepth: 1

   objects_documentobjects
   utilities

|lastupdated|

